with
  text_io,
  ada.integer_text_io,
  ada.long_float_text_io;

use
  text_io,
  ada.integer_text_io,
  ada.long_float_text_io;

procedure slab is

  n,m,nl,i,j                   : integer;
  dx,x,dy,y,ex,dens,prxy,t,k,p : long_float;
  io1,io2                      : file_type;

  procedure scan (io : in text_io.file_type) is

    ascii : character;

  begin
    loop
      text_io.get(io,ascii);
      text_io.skip_line(io);
      exit when ascii = ':';
    end loop;
  end scan;

  function node (i,j : in integer) return integer is

  begin
    return (n + 1) * j + i + 1;
  end node;

  function elem (i,j : in integer) return integer is

  begin
    return (j - 1) * n + i;
  end elem;

begin
  open(io1, in_file, "input.txt");
  create(io2, out_file, "ansys.txt");

  scan(io1);
  get(io1,n);
  get(io1,dx);
  skip_line(io1);

  scan(io1);
  get(io1,m);
  get(io1,dy);
  skip_line(io1);

  scan(io1);
  get(io1,ex);
  get(io1,dens);
  get(io1,prxy);
  skip_line(io1);

  scan(io1);
  get(io1,t);
  get(io1,k);
  skip_line(io1);

  put(io2,"! ENTER THE MODEL CREATION PREPROCESSOR");
  new_line(io2);
  put(io2,"/PREP7");
  new_line(io2);

  new_line(io2);
  put(io2,"! DEFINE NODES");
  new_line(io2);

  for j in 0 .. m loop
    y := dy * long_float(j);
    for i in 0 .. n loop
      x := dx * long_float(i);
      put(io2,"N, ");
      put(io2,node(i,j),5);
      put(io2,", ");
      put(io2,x,2,8,3);
      put(io2,", ");
      put(io2,y,2,8,3);
      put(io2,", ");
      put(io2,"0.00000000E+00");
      new_line(io2);
    end loop;
  end loop;

  new_line(io2);
  put(io2,"! DEFINE MATERIAL PROPERTY");
  new_line(io2);

  put(io2,"MP,   EX, 1, ");
  put(io2,ex,2,8,3);
  new_line(io2);

  put(io2,"MP, DENS, 1, ");
  put(io2,dens,2,8,3);
  new_line(io2);

  put(io2,"MP, PRXY, 1, ");
  put(io2,prxy,2,8,3);
  new_line(io2);

  new_line(io2);
  put(io2,"! DEFINE ELEMENT TYPE");
  new_line(io2);
  put(io2,"ET, 1, SHELL63");
  new_line(io2);

  new_line(io2);
  put(io2,"! DEFINE ELEMENT REAL CONSTANTS");
  new_line(io2);
  put(io2,"R, 1, ");
  put(io2,t,2,8,3);
  put(io2,", , , , ");
  put(io2,k,2,8,3);
  new_line(io2);

  new_line(io2);
  put(io2,"! DEFINE ELEMENTS");
  new_line(io2);

  for j in 1 .. m loop
    for i in 1 .. n loop
      put(io2,"EN, ");
      put(io2,elem(i,j),5);
      put(io2,", ");
      put(io2,node(i - 1,j - 1),5);
      put(io2,", ");
      put(io2,node(i,j - 1),5);
      put(io2,", ");
      put(io2,node(i,j),5);
      put(io2,", ");
      put(io2,node(i - 1,j),5);
      new_line(io2);
    end loop;
  end loop;

  new_line(io2);
  put(io2,"! SPECIFY ACCELERATION");
  new_line(io2);
  put(io2,"ACEL, 0.0, 0.0, 1.0");
  new_line(io2);

  new_line(io2);
  put(io2,"! DEFINE CONSTRAINTS");
  new_line(io2);
  put(io2,"D, 1,   UX, 0.0");
  new_line(io2);
  put(io2,"D, 1,   UY, 0.0");
  new_line(io2);
  put(io2,"D, 1, ROTZ, 0.0");
  new_line(io2);

  new_line(io2);
  put(io2,"! SPECIFY SURFACE LOADS ON ELEMENTS");
  new_line(io2);

  scan(io1);
  get(io1,nl);
  skip_line(io1);

  skip_line(io1);
  for l in 1 .. nl loop
    get(io1,x);
    get(io1,y);
    get(io1,p);
    skip_line(io1);

    i := integer(x / dx);
    j := integer(y / dy);
    p := p / dx / dy / 4.0;

    put(io2,"SFE, ");
    put(io2,elem(i,j),5);
    put(io2,", 2, PRES, 0, ");
    put(io2,p,2,8,3);
    new_line(io2);

    put(io2,"SFE, ");
    put(io2,elem(i + 1,j),5);
    put(io2,", 2, PRES, 0, ");
    put(io2,p,2,8,3);
    new_line(io2);

    put(io2,"SFE, ");
    put(io2,elem(i,j + 1),5);
    put(io2,", 2, PRES, 0, ");
    put(io2,p,2,8,3);
    new_line(io2);

    put(io2,"SFE, ");
    put(io2,elem(i + 1,j + 1),5);
    put(io2,", 2, PRES, 0, ");
    put(io2,p,2,8,3);
    new_line(io2);
  end loop;

  new_line(io2);
  put(io2,"FINISH");
  new_line(io2);

  close(io1);
  close(io2);
end slab;
